/*
 * Copyright (C) 2014 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.test.voiceinteraction;

import android.Manifest;
import android.app.Activity;
import android.content.pm.PackageManager;
import android.net.Uri;
import android.os.Bundle;
import android.support.v4.app.ActivityCompat;
import android.support.v4.content.ContextCompat;
import android.view.View;
import android.view.WindowManager;
import android.widget.CheckBox;
import android.widget.Toast;

public class VoiceInteractionMain extends Activity {

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setContentView(R.layout.main);
        findViewById(R.id.start).setOnClickListener(mStartListener);
        findViewById(R.id.secure).setOnClickListener(mSecureListener);
        if (!isPermissionsGranted()) {
            requestPermissions();
            Toast.makeText(this, "PermissionIsNotgranted", Toast.LENGTH_SHORT).show();
        }
        else {
            Toast.makeText(this, "PermissionIsGranted", Toast.LENGTH_LONG).show();
        }
    }

    private boolean isPermissionsGranted() {
        return ContextCompat.checkSelfPermission(this, Manifest.permission.BIND_VOICE_INTERACTION) == PackageManager.PERMISSION_GRANTED;
    }

    /**
     * Bestätigung der benötigten Rechte wird eingeholt.
     */
    private void requestPermissions() {
        ActivityCompat.requestPermissions(this, new String[] { Manifest.permission.BIND_VOICE_INTERACTION }, 0);
    }

    @Override
    public void onResume() {
        super.onResume();
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
    }

    @Override
    public Uri onProvideReferrer() {
        return Uri.parse("http://www.example.com/VoiceInteractionMain");
    }

    View.OnClickListener mStartListener = new View.OnClickListener() {
        public void onClick(View v) {
            showAssist(null);
        }
    };

    View.OnClickListener mSecureListener = new View.OnClickListener() {
        public void onClick(View v) {
            if (((CheckBox)v).isChecked()) {
                getWindow().addFlags(WindowManager.LayoutParams.FLAG_SECURE);
            } else {
                getWindow().clearFlags(WindowManager.LayoutParams.FLAG_SECURE);
            }
        }
    };
}
